==> zen-cart-v1.2.0-l10n-jp-1.zip: zen-cart-v1.2.0-l10n-jp-1/includes/languages/japanese/gv_faq.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
// $Id: gv_faq.php,v 1.4 2004/11/20 05:54:47 shidairiki Exp $
//

define('NAVBAR_TITLE', TEXT_GV_NAME . 'ˤĤƤ褯');
define('HEADING_TITLE', TEXT_GV_NAME . 'ˤĤƤ褯');

define('TEXT_INFORMATION', '<a name="Top"></a>
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=1','NONSSL').'">' . TEXT_GV_NAMES . 'ˤ</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=2','NONSSL').'">' . TEXT_GV_NAMES . '£ˤ</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=3','NONSSL').'">' . TEXT_GV_NAMES . '򥷥åԥ󥰤˻Ȥˤ</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=4','NONSSL').'">' . TEXT_GV_NAMES . 'Ȥˤ [£줿]</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=5','NONSSL').'">꤬Ȥ</a><br />
');
switch ($_GET['faq_item']) {
  case '1':
define('SUB_HEADING_TITLE',TEXT_GV_NAMES . 'ˤ');
define('SUB_HEADING_TEXT', TEXT_GV_NAMES . 'åפ¾ξʤƱͤˤᤤޤ<br />åפ󶡤Ƥ̾ˡǤʧǤᤤ' . TEXT_GV_NAME . 'ζۤϤͤ' . TEXT_GV_NAME . '¤ɲäޤ<br />ͤ' . TEXT_GV_NAME . '¤˻Ĺ⤬ϥåԥ󥰥ɽ졢᡼' . TEXT_GV_NAME . '£뤿Υ󥯤ɽޤ');
  break;
  case '2':
define('SUB_HEADING_TITLE',TEXT_GV_NAMES . '£ˤ');
define('SUB_HEADING_TEXT', TEXT_GV_NAME . '£뤿ˤϡƥڡΥåԥ󥰥󤫤󥯤줿' . TEXT_GV_NAME . 'ڡ˹ԤιܤƤޤ<br />
-' . TEXT_GV_NAME . 'Τ̾<br />
-' . TEXT_GV_NAME . 'Υ᡼륢ɥ쥹<br />
-£ˤʤ (: ' . TEXT_GV_NAME . ' ¤ˤۤ£ɬפϤޤ)<br />
-᡼źå<br /><br />
ºݤ˳ǧѹǤޤƤξΤˤϤ');
  break;
  case '3':
  define('SUB_HEADING_TITLE',TEXT_GV_NAMES . '򥷥åԥ󥰤˻Ȥˤ');
  define('SUB_HEADING_TEXT','ͤ' . TEXT_GV_NAME . '¤˻Ĺ⤬硢åפǤΤ㤤ʪˤȤޤ<br />ʧˡ򤹤ݤ' . TEXT_GV_NAME . 'εɽޤΤǡ' . TEXT_GV_NAME . '¤λĹ⤫餪ȤˤʤۤϤƲ.¤λĹ⤬ʸۤ­ʤϡ¾Τʧˡ򤷤ƤɬפޤΤǤդ<br />
ʸۤ' . TEXT_GV_NAME . '¤λĹ⤬¿ˤϡ¤˺Ĺ⤬ɽޤ');
  break;
  case '4':
  define('SUB_HEADING_TITLE',TEXT_GV_NAMES . 'Ȥˤ [£줿]');
  define('SUB_HEADING_TEXT','᡼' . TEXT_GV_NAME . '줿ˤϡ᡼' . TEXT_GV_NAME . 'Ծ󤬵ܤƤǤ礦ޤ᡼ˤ' . TEXT_GV_NAME . '' . TEXT_GV_REDEEM . 'ܤƤϤǤλѤ˥᡼ƤȤ褤Ǥ礦<br />
' . TEXT_GV_NAME . 'ˤ2Ĥˡޤ<br /><br />
  1. ȤꤢǤ顢᡼˵ܤƤ󥯤򥯥åŹ' . TEXT_GV_NAME . 'ڡӤޤ󤹤뤫åפΤѤƤξåפΥȤ򤪺ꤤǡ' . TEXT_GV_NAME . 'ͭˤƤѤ' . TEXT_GV_NAME . '¤ѰդƤޤ<br />
  2. åԥ󥰤μ³桢ʧˡ򤹤ڡ' . TEXT_GV_REDEEM . 'Ϥ󤬤ޤ' . TEXT_GV_REDEEM . 'Ϥưܥ򲡤Ʋɤͭˤʤȡ' . TEXT_GV_NAME . '¤⤬ԤޤĹϰǤͳˤȤޤ');
  break;
  case '5':
  define('SUB_HEADING_TITLE','꤬Ȥ');
  define('SUB_HEADING_TEXT','' . TEXT_GV_NAME . 'ƥ˲꤬ޤ顢'. STORE_OWNER_EMAIL_ADDRESS . 'ޤǥ᡼ǤϢ <br />
κݤˤϡ®ΤˤǤܤ(֤ɤβ̤ǡס֤ɤ򤷤פʤ)Τ餻褦ꤤޤ ');
  break;
  default:
  define('SUB_HEADING_TITLE','');
  define('SUB_HEADING_TEXT','μ椫餪Ӥ');

  }
?>

==> zen-cart-v1.3.0.2-l10n-jp-1.zip: zen-cart-v1.3.0.2-l10n-jp-1/includes/languages/japanese/gv_faq.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
// $Id: gv_faq.php 1969 2005-09-13 06:57:21Z drbyte $
//

define('NAVBAR_TITLE', TEXT_GV_NAME . 'ˤĤƤ褯');
define('HEADING_TITLE', TEXT_GV_NAME . 'ˤĤƤ褯');

define('TEXT_INFORMATION', '<a name="Top"></a>
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=1','NONSSL').'">' . TEXT_GV_NAMES . 'ˤ</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=2','NONSSL').'">' . TEXT_GV_NAMES . '£ˤ</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=3','NONSSL').'">' . TEXT_GV_NAMES . '򥷥åԥ󥰤˻Ȥˤ</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=4','NONSSL').'">' . TEXT_GV_NAMES . 'Ȥˤ [£줿]</a><br />
  <a href="'.zen_href_link(FILENAME_GV_FAQ,'faq_item=5','NONSSL').'">꤬Ȥ</a><br />
');
switch ($_GET['faq_item']) {
  case '1':
define('SUB_HEADING_TITLE',TEXT_GV_NAMES . 'ˤ');
define('SUB_HEADING_TEXT', TEXT_GV_NAMES . 'åפ¾ξʤƱͤˤᤤޤ<br />åפ󶡤Ƥ̾ˡǤʧǤᤤ' . TEXT_GV_NAME . 'ζۤϤͤ' . TEXT_GV_NAME . 'Ȥɲäޤ<br />ͤ' . TEXT_GV_NAME . 'Ȥ˻Ĺ⤬ϥåԥ󥰥ɽ졢᡼' . TEXT_GV_NAME . '£뤿Υ󥯤ɽޤ');
  break;
  case '2':
define('SUB_HEADING_TITLE',TEXT_GV_NAMES . '£ˤ');
define('SUB_HEADING_TEXT',TEXT_GV_NAME . '£뤿ˤϡƥڡΥåԥ󥰥󤫤󥯤줿' . TEXT_GV_NAME . 'ڡ˹ԤιܤƤޤ<br />
' . TEXT_GV_NAME . 'Τ̾<br />
' . TEXT_GV_NAME . 'Υ᡼륢ɥ쥹<br />
£ˤʤ (: ' . TEXT_GV_NAME . ' Ȥˤۤ£ɬפϤޤ)<br />
᡼źå<br /><br />
ºݤ˳ǧѹǤޤƤξΤˤϤ');
  break;
  case '3':
  define('SUB_HEADING_TITLE',TEXT_GV_NAMES . '򥷥åԥ󥰤˻Ȥˤ');
  define('SUB_HEADING_TEXT','ͤ' . TEXT_GV_NAME . 'Ȥ˻Ĺ⤬硢åפǤΤ㤤ʪˤȤޤ<br />ʧˡ򤹤ݤ' . TEXT_GV_NAME . 'εɽޤΤǡ' . TEXT_GV_NAME . 'ȤλĹ⤫餪ȤˤʤۤϤƲȤλĹ⤬ʸۤ­ʤϡ¾Τʧˡ򤷤ƤɬפޤΤǤդ<br />
ʸۤ' . TEXT_GV_NAME . 'ȤλĹ⤬¿ˤϡȤ˺Ĺ⤬ɽޤ');
  break;
  case '4':
  define('SUB_HEADING_TITLE',TEXT_GV_NAMES . 'Ȥˤ [£줿]');
  define('SUB_HEADING_TEXT','᡼' . TEXT_GV_NAME . '줿ˤϡ᡼' . TEXT_GV_NAME . 'Ծ󤬵ܤƤǤ礦ޤ᡼ˤ' . TEXT_GV_NAME . '' . TEXT_GV_REDEEM . 'ܤƤϤǤλѤ˥᡼ƤȤ褤Ǥ礦<br />
' . TEXT_GV_NAME . 'ˤ2Ĥˡޤ<br /><br />
 1. ȤꤢǤ顢᡼˵ܤƤ󥯤򥯥åŹ' . TEXT_GV_NAME . 'ڡӤޤ󤹤뤫åפΤѤƤξåפΥȤ򤪺ꤤǡ' . TEXT_GV_NAME . 'ͭˤƤѤ' . TEXT_GV_NAME . 'ȤѰդƤޤ<br />
 2. åԥ󥰤μ³桢ʧˡ򤹤ڡ' . TEXT_GV_REDEEM . 'Ϥ󤬤ޤ' . TEXT_GV_REDEEM . 'Ϥưܥ򲡤Ʋɤͭˤʤȡ' . TEXT_GV_NAME . 'Ȥ⤬ԤޤĹϰǤͳˤȤޤ');
  break;
  case '5':
  define('SUB_HEADING_TITLE','꤬Ȥ');
  define('SUB_HEADING_TEXT','' . TEXT_GV_NAME . 'ƥ˲꤬ޤ顢'. STORE_OWNER_EMAIL_ADDRESS . 'ޤǥ᡼ǤϢ <br />
κݤˤϡ®ΤˤǤܤ(֤ɤβ̤ǡס֤ɤ򤷤פʤ)Τ餻褦ꤤޤ ');
  break;
  default:
  define('SUB_HEADING_TITLE','');
  define('SUB_HEADING_TEXT','μ椫餪Ӥ');

  }
?>
